@@ -61,6 +61,8 @@ class AbstractInterface():
     self.__init_signals()
     self.stop_animation()
 
+    self.post_init()
+
     start_state = int(self.get_config_value('enable-on-startup'))
     self.__switch_state(start_state)
     if start_state:
@@ -72,6 +74,9 @@ class AbstractInterface():
   def pre_init(self):
     pass
 
+  def post_init(self):
+    pass
+
   def turn_on(self):
     pass
 
@@ -157,7 +162,7 @@ class AbstractInterface():
              (self.__name, self.__lcl.get_item(self.state['text'][windex]))
       if len(self.state['modes']) > 1:
         text = '%s (%s)' % \
-               (text, self.__lcl.get(self.state['modes'][self.state['mode']]))
+               (text, self.__lcl.get_item(self.state['modes'][self.state['mode']]))
       HildonBanner.show_information(self.__button, text)
 
   def __init_interfaces(self):
@@ -256,7 +261,7 @@ class AbstractInterface():
     return zip(texts, [self.__turn_state for t in texts])
 
   def __get_mode_controls(self):
-    texts = map(self.__lcl.get, list(self.state['modes']))
+    texts = map(self.__lcl.get_item, list(self.state['modes']))
     return zip(texts, [self.__turn_mode for t in texts])
 
   def __turn_state(self, widget=None, control=None, cstate=None):
