@@ -25,6 +25,7 @@ class WLANInterface(AbstractInterface):
   wifi_icdui_iface = 'com.nokia.icd_ui'
 
   def pre_init(self):
+    self.autooff = None
     self.has_be = get_shell_command_output('ls /lib/modules/$(uname -r) | grep -m 1 wl1251') != ''
     self.state = {'name': 'WLAN',
                   'dbus': {'on': {'name': self.wifi_module_signal, 
@@ -63,6 +64,9 @@ class WLANInterface(AbstractInterface):
                                   self.wifi_icdui_iface, '/usr/sbin/icd2', 
                                   False]}
 
+  def post_init(self):
+    self.set_config_option('disconnected-timeout', (-1,10,30,60,300))
+
   def process_signal_on(self, *args, **kwargs):
     if args[0] == '/org/freedesktop/Hal/devices/platform_wl12xx':
       state = int(kwargs['member'] == 'DeviceAdded')
@@ -76,9 +80,15 @@ class WLANInterface(AbstractInterface):
   def process_signal_connected(self, *args):
     if len(args) == 8 and args[3].startswith('WLAN_'):
       if args[7] == 2:
+        if self.autooff:
+          gobject.source_remove(self.autooff)
+          self.autooff = None
         gobject.timeout_add(1000, self.get_strength)
         return 2, 0, None
       elif args[7] == 0 and self.state['value'] != 0:
+        autooff = int(self.get_config_value('disconnected-timeout'))
+        if autooff > 0 and self.state['value'] == 2:
+          self.autooff = gobject.timeout_add(autooff*1000, self.turn_off)
         return 1, 0, None
       else:
         return self.state['value'], 0, None
@@ -106,8 +116,10 @@ class WLANInterface(AbstractInterface):
         self.get_interface('ICD').disconnect_req(dbus.UInt32(0x8000))
       except:
         self.reinit_interface('ICD')
+    return False
 
   def turn_off(self):
+    self.autooff = None
     if self.state['value'] > 0:
       if self.state['value'] == 2:
         try:
@@ -116,6 +128,7 @@ class WLANInterface(AbstractInterface):
           self.reinit_interface('ICD')
       #run_async(self.run_commands, (self.wifi_turn_off_cmd,))
       gobject.idle_add(self.run_commands, self.wifi_turn_off_cmd)
+    return False
 
   def run_commands(self, cmds):
     run_shell_command(' && '.join(cmds))
