@@ -21,18 +21,24 @@ class AISLocale(Locale):
                          'item-Connected': 'Connected',
                          'item-<>': '<>',
                          'settings-other': 'Other',
-                         'gsm-3g+gsm': '3G+GSM',
-                         'gsm-2g': '2G',
-                         'gsm-3g': '3G',
-                         'bluetooth-connectable': 'Connectable',
-                         'bluetooth-discoverable': 'Discoverable',
-                         'wlan-stock': 'Stock',
-                         'wlan-bleeding-edge': 'Bleeding Edge',
+                         'item-gsm-3g+gsm': '3G+GSM',
+                         'item-gsm-2g': '2G',
+                         'item-gsm-3g': '3G',
+                         'item-bluetooth-connectable': 'Connectable',
+                         'item-bluetooth-discoverable': 'Discoverable',
+                         'item-wlan-stock': 'Stock',
+                         'item-wlan-bleeding-edge': 'Bleeding Edge',
                          'show-state-dialog': 'Show dialog on click',
                          'enable-on-startup': 'Enable on startup',
                          'mode-on-startup': 'Enabled mode on startup',
                          'show-popups': 'Show popups',
-                         'show-connection-dialog': 'Show connection dialog'
+                         'show-connection-dialog': 'Show connection dialog',
+                         'disconnected-timeout': 'Autodisable',
+                         'item--1': 'Never',
+                         'item-10': 'After 10 seconds',
+                         'item-30': 'After 30 seconds',
+                         'item-60': 'After 1 minute',
+                         'item-300': 'After 5 minutes',
                         }
 
 __locale_singleton = AISLocale()
